package com.bs.ct.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bs.common.annotation.Log;
import com.bs.common.core.controller.BaseController;
import com.bs.common.core.domain.AjaxResult;
import com.bs.common.core.page.TableDataInfo;
import com.bs.common.enums.BusinessType;
import com.bs.common.utils.poi.ExcelUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import cn.hutool.core.lang.Validator;
import com.bs.ct.domain.CtTaskTemplate;
import com.bs.ct.service.ICtTaskTemplateService;
import javax.annotation.Resource;

/**
 * 任务模板Controller
 *
 * @author bs
 * @date 2025-02-22
 */
@Api(tags = "任务模板")
@RestController
@RequestMapping("/task/template")
public class CtTaskTemplateController extends BaseController {
    @Resource
    private ICtTaskTemplateService ctTaskTemplateService;

    /**
     * 分页查询任务模板列表
     */
    @ApiOperation("分页查询任务模板列表")
    @GetMapping("/pageList")
    public TableDataInfo pageList(CtTaskTemplate ctTaskTemplate) {
        startPage();
        LambdaQueryWrapper<CtTaskTemplate> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,ctTaskTemplate);
        List<CtTaskTemplate> list = ctTaskTemplateService.list(queryWrapper);
        return getDataTable(list);
    }

    /**
     * 查询任务模板列表
     */
    @ApiOperation("查询任务模板列表")
    @GetMapping("/list")
    public AjaxResult list(CtTaskTemplate ctTaskTemplate) {
        LambdaQueryWrapper<CtTaskTemplate> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,ctTaskTemplate);
        List<CtTaskTemplate> list = ctTaskTemplateService.list(queryWrapper);
        return success(list);
    }

    /**
     * 导出任务模板列表
     */
    @ApiOperation("导出任务模板列表")
    @Log(title = "任务模板导出", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CtTaskTemplate ctTaskTemplate) {
        LambdaQueryWrapper<CtTaskTemplate> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,ctTaskTemplate);
        List<CtTaskTemplate> list = ctTaskTemplateService.list(queryWrapper);
        ExcelUtil<CtTaskTemplate> util = new ExcelUtil<CtTaskTemplate>(CtTaskTemplate. class);
        util.exportExcel(response, list, "任务模板数据");
    }

    /**
     * 获取任务模板详细信息
     */
    @ApiOperation("获取任务模板详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(ctTaskTemplateService.getById(id));
    }

    /**
     * 新增任务模板
     */
    @ApiOperation("新增任务模板")
    @Log(title = "任务模板新增", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CtTaskTemplate ctTaskTemplate) {
        return toAjax(ctTaskTemplateService.save(ctTaskTemplate));
    }

    /**
     * 修改任务模板
     */
    @ApiOperation("修改任务模板")
    @Log(title = "任务模板修改", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CtTaskTemplate ctTaskTemplate) {
        return toAjax(ctTaskTemplateService.updateById(ctTaskTemplate));
    }

    /**
     * 删除任务模板
     */
    @ApiOperation("删除任务模板")
    @Log(title = "任务模板删除", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids) {
        return toAjax(ctTaskTemplateService.removeBatchByIds(ids));
    }

    /**
      * 条件设置
      */
    private void condition (LambdaQueryWrapper<CtTaskTemplate> queryWrapper,CtTaskTemplate ctTaskTemplate){


        //id
        if(Validator.isNotEmpty(ctTaskTemplate.getId())){
            queryWrapper.eq(CtTaskTemplate::getId,ctTaskTemplate.getId());
        }

        //任务类型
        if(Validator.isNotEmpty(ctTaskTemplate.getTaskType())){
            queryWrapper.eq(CtTaskTemplate::getTaskType,ctTaskTemplate.getTaskType());
        }

        //模板名称
        if(Validator.isNotEmpty(ctTaskTemplate.getTemplateName())){
            queryWrapper.eq(CtTaskTemplate::getTemplateName,ctTaskTemplate.getTemplateName());
        }

        //任务标题
        if(Validator.isNotEmpty(ctTaskTemplate.getTaskTitle())){
            queryWrapper.eq(CtTaskTemplate::getTaskTitle,ctTaskTemplate.getTaskTitle());
        }

        //任务要求
        if(Validator.isNotEmpty(ctTaskTemplate.getTaskContent())){
            queryWrapper.eq(CtTaskTemplate::getTaskContent,ctTaskTemplate.getTaskContent());
        }

        //备注
        if(Validator.isNotEmpty(ctTaskTemplate.getRemarks())){
            queryWrapper.eq(CtTaskTemplate::getRemarks,ctTaskTemplate.getRemarks());
        }

        //删除标志（0代表存在 2代表删除）
        if(Validator.isNotEmpty(ctTaskTemplate.getDelFlag())){
            queryWrapper.eq(CtTaskTemplate::getDelFlag,ctTaskTemplate.getDelFlag());
        }

        //创建部门
        if(Validator.isNotEmpty(ctTaskTemplate.getCreateDept())){
            queryWrapper.eq(CtTaskTemplate::getCreateDept,ctTaskTemplate.getCreateDept());
        }

        //创建人
        if(Validator.isNotEmpty(ctTaskTemplate.getCreateBy())){
            queryWrapper.eq(CtTaskTemplate::getCreateBy,ctTaskTemplate.getCreateBy());
        }

        //创建时间
        if(Validator.isNotEmpty(ctTaskTemplate.getCreateTime())){
            queryWrapper.eq(CtTaskTemplate::getCreateTime,ctTaskTemplate.getCreateTime());
        }

        //修改人
        if(Validator.isNotEmpty(ctTaskTemplate.getUpdateBy())){
            queryWrapper.eq(CtTaskTemplate::getUpdateBy,ctTaskTemplate.getUpdateBy());
        }

        //修改时间
        if(Validator.isNotEmpty(ctTaskTemplate.getUpdateTime())){
            queryWrapper.eq(CtTaskTemplate::getUpdateTime,ctTaskTemplate.getUpdateTime());
        }

        //租户ID
        if(Validator.isNotEmpty(ctTaskTemplate.getTenantId())){
            queryWrapper.eq(CtTaskTemplate::getTenantId,ctTaskTemplate.getTenantId());
        }

        }

}
